package cn.efunbox.audio.impl;

import cn.efunbox.audio.consts.MediaType;
import cn.efunbox.audio.entity.Audio;
import cn.efunbox.audio.entity.Device;
import cn.efunbox.audio.repository.AudioRepo;
import cn.efunbox.audio.repository.DeviceRepo;
import cn.efunbox.audio.service.AudioService;
import cn.efunbox.audio.service.DeviceService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.PageRequest;
import org.springframework.data.domain.Pageable;
import org.springframework.stereotype.Service;

import java.util.ArrayList;
import java.util.Date;
import java.util.List;
import java.util.UUID;

/**
 * Created by yao on 17-9-26.
 */
@Service
public class AudioServiceImpl implements AudioService {

    @Autowired
    AudioRepo audioRepo;

    @Override
    public Audio GetOne(Long id){
        Audio audio = audioRepo.findById(id);
        return audio;
    }

    @Override
    public Page<Audio> SearchAll(int mediaType, int page, int size){
        if(size<=0)
            size = 50;
        Pageable pageable = new PageRequest(page, size);
        Page<Audio> list = null;
        if(mediaType== MediaType.AUDIO.getCode() || mediaType==MediaType.VIDEO.getCode())
            list = audioRepo.findByMediaType(mediaType, pageable);
        else
            list = audioRepo.findAll(pageable);
        return list;
    }

    @Override
    public Page<Audio> SearchByIdGroup(int mediaType, Long idGroup, int page, int size){
        if(size<=0)
            size = 50;
        Pageable pageable = new PageRequest(page, size);
        Page<Audio> list = null;
        if(mediaType== MediaType.AUDIO.getCode() || mediaType==MediaType.VIDEO.getCode())
            list = audioRepo.findByMediaTypeAndIdGroup(mediaType, idGroup, pageable);
        else
            list = audioRepo.findByIdGroup(idGroup, pageable);
        return list;
    }

    @Override
    public List<Audio> SearchByName(int mediaType, String name){
        if(name==null || name.isEmpty())
            return null;
        List<Audio> list = null;
        if(mediaType== MediaType.AUDIO.getCode() || mediaType==MediaType.VIDEO.getCode())
            list = audioRepo.findByMediaTypeAndName(mediaType, name);
        else
            list = audioRepo.findByName(name);
//        System.out.println("list1:"+list.toString());

        if(list==null){
            list = audioRepo.findByNameLike(name);
            System.out.println("list:"+list.toString());
        }
//        System.out.println("list2:"+list.toString());
        return list;
    }

    @Override
    public List<Audio> SearchByAlbum(int mediaType, String album){
        if(album==null || album.isEmpty())
            return null;
        List<Audio> list = null;
        if(mediaType== MediaType.AUDIO.getCode() || mediaType==MediaType.VIDEO.getCode())
            list = audioRepo.findByMediaTypeAndAlbum(mediaType, album);
        else
            list = audioRepo.findByAlbum(album);
        if(list==null)
            list = audioRepo.findByAlbumLike(album);
        return list;
    }

    @Override
    public List<Audio> SearchByNameAlbum(int mediaType, String name, String album){
        if(name==null || name.isEmpty()
                || album==null || album.isEmpty())
            return null;
        List<Audio> list = null;
        if(mediaType== MediaType.AUDIO.getCode() || mediaType==MediaType.VIDEO.getCode())
            list = audioRepo.findByMediaTypeAndNameAndAlbum(mediaType, name, album);
        else
            list = audioRepo.findByNameAndAlbum(name, album);
        if(list==null)
            list = audioRepo.searchByNameAndAlbum(name, album);

        return list;
    }

    @Override
    public Audio Insert(Audio audio){
        Audio a = audioRepo.save(audio);
        return a;
    }

    @Override
    public void Delete(Long id){
        audioRepo.delete(id);
    }

}
